// background.js
chrome.runtime.onMessage.addListener(async (message, sender, sendResponse) => {
    if (message.action === "checkJobs") {
        const jobs = message.jobs;
        console.log('Checking job URLs:', jobs);
        for (let job of jobs) {
            try {
                const response = await fetch(job.url);
                const text = await response.text();
                if (!text.includes("Last viewed by client")) {
                    chrome.scripting.executeScript({
                        target: { tabId: sender.tab.id },
                        func: hideArticle,
                        args: [job.articleId]
                    });
                    chrome.runtime.sendMessage({ action: 'log', message: `Hiding article ${job.articleId}` });
                }
            } catch (error) {
                console.error('Error fetching job URL:', error);
                chrome.runtime.sendMessage({ action: 'log', message: `Error fetching ${job.url}` });
            }
        }
        sendResponse({ status: 'done' });
        chrome.runtime.sendMessage({ action: 'log', message: 'Job filtering done.' });
    }
});

function hideArticle(articleId) {
    const article = document.querySelector(`#${articleId}`);
    if (article) {
        article.style.display = 'none';
    }
}
