// content.js

chrome.runtime.onMessage.addListener(async (message, sender, sendResponse) => {
    if (message.action === "fetchJobUrls") {
        const jobUrls = [];
        document.querySelectorAll('article.job-tile:not([style*="display: none"])').forEach((article, index) => {
            const anchor = article.querySelector('a.up-n-link');
            if (anchor) {
                // Assign a unique ID to each article if it doesn't have one
                if (!article.id) {
                    article.id = `job-tile-${index}`;
                }
                jobUrls.push({ url: anchor.href, articleId: article.id });
            }
        });
        console.log('Job URLs fetched:', jobUrls);
        sendResponse({ status: 'done', jobUrls: jobUrls });
    }

    if (message.action === "checkJobs") {
        const jobs = message.jobs;
        console.log('Checking job URLs:', jobs);
        createOverlay();
        for (let i = 0; i < jobs.length; i++) {
            const job = jobs[i];
            try {
                const response = await fetch(job.url);
                const text = await response.text();
                if (!text.includes("Last viewed by client")) {
                    hideArticle(job.articleId);
                    updateOverlay(`Hiding article ${job.articleId}`);
                }
                updateProgressOverlay(((i + 1) / jobs.length) * 100);
            } catch (error) {
                console.error('Error fetching job URL:', error);
                updateOverlay(`Error fetching ${job.url}: ${error.message}`);
            }
        }
        updateOverlay('Job filtering done.');
        removeOverlayAfterDelay(1000); // Remove overlay after 5 seconds
        sendResponse({ status: 'done' });
    }
});

function hideArticle(articleId) {
    const article = document.querySelector(`#${articleId}`);
    if (article) {
        article.style.display = 'none';
    }
}

function createOverlay() {
    const overlay = document.createElement('div');
    overlay.id = 'jobFilterOverlay';
    overlay.style.position = 'fixed';
    overlay.style.top = '0';
    overlay.style.left = '0';
    overlay.style.width = '100%';
    overlay.style.height = '100%';
    overlay.style.backgroundColor = 'rgba(0, 0, 0, 0.5)';
    overlay.style.color = 'white';
    overlay.style.zIndex = '9999';
    overlay.style.padding = '20px';
    overlay.style.overflowY = 'auto';
    document.body.appendChild(overlay);

    const progress = document.createElement('div');
    progress.id = 'jobFilterProgress';
    progress.style.marginBottom = '10px';
    overlay.appendChild(progress);

    const messages = document.createElement('div');
    messages.id = 'jobFilterMessages';
    overlay.appendChild(messages);
}

function updateOverlay(message) {
    const messages = document.getElementById('jobFilterMessages');
    const messageElement = document.createElement('p');
    messageElement.textContent = message;
    messages.appendChild(messageElement);
}

function updateProgressOverlay(progress) {
    const progressElement = document.getElementById('jobFilterProgress');
    progressElement.textContent = `Progress: ${progress.toFixed(2)}%`;
}

function removeOverlay() {
    const overlay = document.getElementById('jobFilterOverlay');
    if (overlay) {
        overlay.remove();
    }
}

function removeOverlayAfterDelay(delay) {
    setTimeout(removeOverlay, delay);
}
